@@ -1,4 +1,4 @@
-import bpkio_api.helpers.handlers as handlers
+import media_muncher.handlers as handlers
 from bpkio_api.exceptions import BroadpeakIoHelperError
 from bpkio_api.models.Sources import SourceType
 
